import { ComponentFactory } from "@angular/core";
import { HttpOptionsArgs } from "./http.meta";
import { HttpResponse } from "@angular/common/http";
import { ModalItem } from "./modal.meta";
/**
 * 动态组件创建
 */
export interface DynamicComponentFactoryProvider {
    /**
     * 主模块提供字符串selector和component factory映射级
     */
    getComponentFactoryMap(): {
        [index: string]: ComponentFactory<any>;
    };
}
/**
 * 获取baseUrl
 */
export interface HttpProvider {
    getBaseUrl(): string;
    requestIntercept(options: HttpOptionsArgs): boolean;
    successIntercept(data: any, response: HttpResponse<any>, options: HttpOptionsArgs): boolean;
    errorIntercept(response: HttpResponse<any>, options: HttpOptionsArgs): boolean;
}
/**
 * city城市列表
 */
export interface CityProvider {
    getCityUrl(): string;
}
/**
 * 文件上传
 */
export interface FileUploadProvider {
    getFileServerBaseUrl(): string;
    getFileServerUserToken(): string;
}
export interface FileProvider {
    getFileBaseUrl(): string;
}
export interface LocationProvider {
    getAnalysisCityUrl(): string;
}
export interface SelectAreaProvider {
    getAreaUrl(): string;
}
/**
 * 微信获取配置文件
 */
export interface WeChatProvider {
    getWeChatConfigUrl(): string;
}
/**
 * 模态框打开关闭
 */
export interface ModalContainerProvider {
    openModal(modalItem: ModalItem): void;
    closeModal(modalItem: ModalItem): void;
}
export interface CoreProvider {
    dynamicComponentFactoryProvider?: DynamicComponentFactoryProvider;
    httpProvider?: HttpProvider;
    cityProvider?: CityProvider;
    fileUploadProvider?: FileUploadProvider;
    fileProvider?: FileProvider;
    locationProvider?: LocationProvider;
    selectAreaProvider?: SelectAreaProvider;
    weChatProvider?: WeChatProvider;
    modalContainerProvider?: ModalContainerProvider;
}
